aboutsummaryrefslogtreecommitdiff
path: root/codegen/lib/download.py
diff options
context:
space:
mode:
authormat <27899617+mat-1@users.noreply.github.com>2023-07-14 22:20:40 -0500
committerGitHub <noreply@github.com>2023-07-14 22:20:40 -0500
commit7405427199e5a994d4a6a706f84434a69cb7a7d9 (patch)
treeca537e5d761bc053187d952fced0915c850b92aa /codegen/lib/download.py
parentd1afd02aa84e7b4450c1607277f078eb2a0f1bf3 (diff)
downloadazalea-drasl-7405427199e5a994d4a6a706f84434a69cb7a7d9.tar.xz
Mining (#95)
* more mining stuff * initialize azalea-tags crate * more mining stuff 2 * mining in ecs * well technically mining works but no codegen for how long it takes to mine each block yet * rename downloads to __cache__ it was bothering me since it's not *just* downloads * codegen block behavior * fix not sending packet to finish breaking block * mining animation 🎉 * clippy * cleanup, move Client::mine into a client extension * add azalea/src/mining.rs --------- Co-authored-by: mat <git@matdoes.dev>
Diffstat (limited to 'codegen/lib/download.py')
-rwxr-xr-xcodegen/lib/download.py76
1 files changed, 38 insertions, 38 deletions
diff --git a/codegen/lib/download.py b/codegen/lib/download.py
index 1b22fbcc..319c6080 100755
--- a/codegen/lib/download.py
+++ b/codegen/lib/download.py
@@ -5,47 +5,47 @@ import requests
import json
import os
-# make sure the downloads directory exists
-print('Making downloads')
-if not os.path.exists(get_dir_location('downloads')):
- print('Made downloads directory.', get_dir_location('downloads'))
- os.mkdir(get_dir_location('downloads'))
+# make sure the cache directory exists
+print('Making __cache__')
+if not os.path.exists(get_dir_location('__cache__')):
+ print('Made __cache__ directory.', get_dir_location('__cache__'))
+ os.mkdir(get_dir_location('__cache__'))
def get_burger():
- if not os.path.exists(get_dir_location('downloads/Burger')):
+ if not os.path.exists(get_dir_location('__cache__/Burger')):
print('\033[92mDownloading Burger...\033[m')
os.system(
- f'cd {get_dir_location("downloads")} && git clone https://github.com/pokechu22/Burger && cd Burger && git pull')
+ f'cd {get_dir_location("__cache__")} && git clone https://github.com/pokechu22/Burger && cd Burger && git pull')
print('\033[92mInstalling dependencies...\033[m')
- os.system(f'cd {get_dir_location("downloads")}/Burger && pip install six jawa')
+ os.system(f'cd {get_dir_location("__cache__")}/Burger && pip install six jawa')
def get_pixlyzer():
- if not os.path.exists(get_dir_location('downloads/pixlyzer')):
+ if not os.path.exists(get_dir_location('__cache__/pixlyzer')):
print('\033[92mDownloading bixilon/pixlyzer...\033[m')
os.system(
- f'cd {get_dir_location("downloads")} && git clone https://gitlab.bixilon.de/bixilon/pixlyzer.git && cd pixlyzer && git pull')
- return get_dir_location('downloads/pixlyzer')
+ f'cd {get_dir_location("__cache__")} && git clone https://gitlab.bixilon.de/bixilon/pixlyzer.git && cd pixlyzer && git pull')
+ return get_dir_location('__cache__/pixlyzer')
def get_version_manifest():
- if not os.path.exists(get_dir_location(f'downloads/version_manifest.json')):
+ if not os.path.exists(get_dir_location(f'__cache__/version_manifest.json')):
print(
f'\033[92mDownloading version manifest...\033[m')
version_manifest_data = requests.get(
'https://piston-meta.mojang.com/mc/game/version_manifest_v2.json').json()
- with open(get_dir_location(f'downloads/version_manifest.json'), 'w') as f:
+ with open(get_dir_location(f'__cache__/version_manifest.json'), 'w') as f:
json.dump(version_manifest_data, f)
else:
- with open(get_dir_location(f'downloads/version_manifest.json'), 'r') as f:
+ with open(get_dir_location(f'__cache__/version_manifest.json'), 'r') as f:
version_manifest_data = json.load(f)
return version_manifest_data
def get_version_data(version_id: str):
- if not os.path.exists(get_dir_location(f'downloads/{version_id}.json')):
+ if not os.path.exists(get_dir_location(f'__cache__/{version_id}.json')):
version_manifest_data = get_version_manifest()
print(
@@ -55,60 +55,60 @@ def get_version_data(version_id: str):
filter(lambda v: v['id'] == version_id, version_manifest_data['versions']))['url']
except StopIteration:
raise ValueError(
- f'No version with id {version_id} found. Maybe delete downloads/version_manifest.json and try again?')
+ f'No version with id {version_id} found. Maybe delete __cache__/version_manifest.json and try again?')
package_data = requests.get(package_url).json()
- with open(get_dir_location(f'downloads/{version_id}.json'), 'w') as f:
+ with open(get_dir_location(f'__cache__/{version_id}.json'), 'w') as f:
json.dump(package_data, f)
else:
- with open(get_dir_location(f'downloads/{version_id}.json'), 'r') as f:
+ with open(get_dir_location(f'__cache__/{version_id}.json'), 'r') as f:
package_data = json.load(f)
return package_data
def get_client_jar(version_id: str):
- if not os.path.exists(get_dir_location(f'downloads/client-{version_id}.jar')):
+ if not os.path.exists(get_dir_location(f'__cache__/client-{version_id}.jar')):
package_data = get_version_data(version_id)
print('\033[92mDownloading client jar...\033[m')
client_jar_url = package_data['downloads']['client']['url']
- with open(get_dir_location(f'downloads/client-{version_id}.jar'), 'wb') as f:
+ with open(get_dir_location(f'__cache__/client-{version_id}.jar'), 'wb') as f:
f.write(requests.get(client_jar_url).content)
def get_server_jar(version_id: str):
- if not os.path.exists(get_dir_location(f'downloads/server-{version_id}.jar')):
+ if not os.path.exists(get_dir_location(f'__cache__/server-{version_id}.jar')):
package_data = get_version_data(version_id)
print('\033[92mDownloading server jar...\033[m')
server_jar_url = package_data['downloads']['server']['url']
- with open(get_dir_location(f'downloads/server-{version_id}.jar'), 'wb') as f:
+ with open(get_dir_location(f'__cache__/server-{version_id}.jar'), 'wb') as f:
f.write(requests.get(server_jar_url).content)
def get_mappings_for_version(version_id: str):
- if not os.path.exists(get_dir_location(f'downloads/mappings-{version_id}.txt')):
+ if not os.path.exists(get_dir_location(f'__cache__/mappings-{version_id}.txt')):
package_data = get_version_data(version_id)
client_mappings_url = package_data['downloads']['client_mappings']['url']
mappings_text = requests.get(client_mappings_url).text
- with open(get_dir_location(f'downloads/mappings-{version_id}.txt'), 'w') as f:
+ with open(get_dir_location(f'__cache__/mappings-{version_id}.txt'), 'w') as f:
f.write(mappings_text)
else:
- with open(get_dir_location(f'downloads/mappings-{version_id}.txt'), 'r') as f:
+ with open(get_dir_location(f'__cache__/mappings-{version_id}.txt'), 'r') as f:
mappings_text = f.read()
return Mappings.parse(mappings_text)
def get_yarn_versions():
# https://meta.fabricmc.net/v2/versions/yarn
- if not os.path.exists(get_dir_location('downloads/yarn_versions.json')):
+ if not os.path.exists(get_dir_location('__cache__/yarn_versions.json')):
print('\033[92mDownloading yarn versions...\033[m')
yarn_versions_data = requests.get(
'https://meta.fabricmc.net/v2/versions/yarn').json()
- with open(get_dir_location('downloads/yarn_versions.json'), 'w') as f:
+ with open(get_dir_location('__cache__/yarn_versions.json'), 'w') as f:
json.dump(yarn_versions_data, f)
else:
- with open(get_dir_location('downloads/yarn_versions.json'), 'r') as f:
+ with open(get_dir_location('__cache__/yarn_versions.json'), 'r') as f:
yarn_versions_data = json.load(f)
return yarn_versions_data
@@ -121,7 +121,7 @@ def get_yarn_data(version_id: str):
def get_fabric_api_versions():
# https://maven.fabricmc.net/net/fabricmc/fabric-api/fabric-api/maven-metadata.xml
- if not os.path.exists(get_dir_location('downloads/fabric_api_versions.json')):
+ if not os.path.exists(get_dir_location('__cache__/fabric_api_versions.json')):
print('\033[92mDownloading Fabric API versions...\033[m')
fabric_api_versions_xml_text = requests.get(
'https://maven.fabricmc.net/net/fabricmc/fabric-api/fabric-api/maven-metadata.xml').text
@@ -138,17 +138,17 @@ def get_fabric_api_versions():
for version_el in versions_el.findall('version'):
fabric_api_versions.append(version_el.text)
- with open(get_dir_location('downloads/fabric_api_versions.json'), 'w') as f:
+ with open(get_dir_location('__cache__/fabric_api_versions.json'), 'w') as f:
f.write(json.dumps(fabric_api_versions))
else:
- with open(get_dir_location('downloads/fabric_api_versions.json'), 'r') as f:
+ with open(get_dir_location('__cache__/fabric_api_versions.json'), 'r') as f:
fabric_api_versions = json.loads(f.read())
return fabric_api_versions
def get_fabric_loader_versions():
# https://meta.fabricmc.net/v2/versions/loader
- if not os.path.exists(get_dir_location('downloads/fabric_loader_versions.json')):
+ if not os.path.exists(get_dir_location('__cache__/fabric_loader_versions.json')):
print('\033[92mDownloading Fabric loader versions...\033[m')
fabric_api_versions_json = requests.get(
'https://meta.fabricmc.net/v2/versions/loader').json()
@@ -157,10 +157,10 @@ def get_fabric_loader_versions():
for version in fabric_api_versions_json:
fabric_api_versions.append(version['version'])
- with open(get_dir_location('downloads/fabric_loader_versions.json'), 'w') as f:
+ with open(get_dir_location('__cache__/fabric_loader_versions.json'), 'w') as f:
f.write(json.dumps(fabric_api_versions))
else:
- with open(get_dir_location('downloads/fabric_loader_versions.json'), 'r') as f:
+ with open(get_dir_location('__cache__/fabric_loader_versions.json'), 'r') as f:
fabric_api_versions = json.loads(f.read())
return fabric_api_versions
@@ -174,14 +174,14 @@ def clear_version_cache():
'fabric_loader_versions.json'
]
for file in files:
- if os.path.exists(get_dir_location(f'downloads/{file}')):
- os.remove(get_dir_location(f'downloads/{file}'))
+ if os.path.exists(get_dir_location(f'__cache__/{file}')):
+ os.remove(get_dir_location(f'__cache__/{file}'))
- burger_path = get_dir_location("downloads/Burger")
+ burger_path = get_dir_location("__cache__/Burger")
if os.path.exists(burger_path):
os.system(
f'cd {burger_path} && git pull')
- pixlyzer_path = get_dir_location('downloads/pixlyzer')
+ pixlyzer_path = get_dir_location('__cache__/pixlyzer')
if os.path.exists(pixlyzer_path):
os.system(
f'cd {pixlyzer_path} && git pull') \ No newline at end of file